# ECE 140: Linear Circuits

## Voltage, current, and resistance

Please see [SL Physics 1#Electric potential](/g11/sph3u7#electric-potential) for more information on voltage.

Please see [SL Physics 1#5.2 - Heating effect of electric currents](/g11/sph3u7/#52-heating-effect-of-electric-currents) for more information on current.

Please see [SL Physics 1#Resistance](/g11/sph3u7/#resistance) for more information on resistance.

**Electric charge** $Q$ quantises the charge of electrons and positive ions, and is expressed in coulombs (**C**).

Objects with charge generate electric fields, thus granting potential energy that is released upon proximity to another charge.

!!! warning
    Voltage and current are capitalised in **direct current only** ($V$, $I$). In general use, their lowercase forms should be used instead ($v, $i$).

**Voltage** is related to the change in energy ($dw$) over the change in charge ($dq$), or alternatively through Ohm's law:

$$i=\frac{dw}{dq}=\frac{i}{R}$$

**Current** represents the rate of flow of charge in amps (**A**). Conventional current moves opposite electron flow because old scientists couldn't figure it out properly.

$$i=\frac{dq}{dt}\approx \frac{\Delta q}{\Delta t}$$

### Power

Power represents the rate of doing work, in unit watts ($\pu W$, \pu{J/s})

$$P=\frac{dw}{dt}$$

It is also directly related to voltage and current:

$$P=vi$$

Much like relative velocity, power is directional and relative, with a positive sign indicating the direction of conventional current.

$$P_{CB}=-P_{BC}$$

In a closed system, conservation of energy applies:

$$\sum P_\text{in}=\sum P_\text{out}$$

The **ground** is the "absolute zero" voltage with a maximum potential difference. It is also known as the "reference voltage".

### Independent energy sources

!!! definition
    - A **ground** is the reference point that all **potential differences are relative to**.

A **generic voltage source** provides a known potential difference between its two terminals that is defined by the source. The resultant current can be calculated.

<img src="https://upload.wikimedia.org/wikipedia/commons/f/ff/Voltage_Source.svg" width=100>(Source: Wikimedia Commons)</img>

A **generic current source** provides a known amperage between its two terminals that is defined by the source. The resultant voltage can be calculated.

<img src="https://upload.wikimedia.org/wikipedia/commons/b/b2/Current_Source.svg" width=100>(Source: Wikimedia Commons)</img>

!!! tip
    A current in the **positive direction** indicates that the source is releasing power (is a source). Otherwise, it is consuming power (is a load).

### Dependent energy sources

A **dependent <&ZeroWidthSpace;T: voltage | current> source** has a **T** dependent on the voltage or current elsewhere in the circuit. $k$ is a function that is likely but not guaranteed to be linear.

$$
v=kv_0\ |\ ki_0 \\
i=kv_0\ |\ ki_0
$$

<img src="https://upload.wikimedia.org/wikipedia/commons/5/55/Voltage_Source_%28Controlled%29.svg" width=100>(Source: Wikimedia Commons)</img>

<img src="https://upload.wikimedia.org/wikipedia/commons/f/fe/Current_Source_%28Controlled%29.svg" width=100>(Source: Wikimedia Commons)</img>

### Applications

A **cathode ray tube** produces an electron beam of variable intensity depending on the input signal. Electrons are deflected by the screen to produce imagery.

<img src="/resources/images/crt.png" />

### Resistance

A **resistor** *always absorbs power*, so must be oriented such that current goes into the positive sign.

According to Ohm's law, the voltage, current, and resistance are related:

$$v=iR$$

The **conductance** of a resistor is the inverse of its resistance, and is expressed in siemens ($\pu{S}$)

$$G=\frac 1 R = \frac I V$$

Therefore, power can be expressed by manipulating the equations:

$$
\begin{align*}
P &= IR^2 \\
&= V^2G \\
&= \frac{V^2}{R}
\end{align*}
$$

## Kirchhoff's laws

!!! definition
    - A **node** is any point in the circuit to which 3+ elements are *directly* connected (i.e., all junctions).
    - A **supernode** is any connected group in the circuit to which 3+ elements are *directly* connected.
    - A **loop** is any closed path of elements.

Kirchhoff's **current law** states that the sum of all current entering a node must be zero, where positive indicates current entrance.

$$\sum i_\text{entering node}=0$$

Kirchoff's **voltage law** states that the sum of all voltage in a **closed loop** must be zero.

$$\sum v_\text{loop}=0$$

### Nodal analysis

Nodal analysis uses the voltages at the **nodes** instead of elements to calculate things in a three-step process:

1. Determine a reference node with $v=0$ and stick a ground out of that node.
2. Use KCL and Ohm's law on non-reference nodes to get their currents in terms of the reference node.
3. Solve the system of equations with the formula below.

On either side of a resistor, the current flowing that entire segment can be determined via the following formula:

$$i=\frac{v_\text{higher}-v_\text{lower}}{R}$$

### Mesh analysis

!!! definition
    - A **mesh** is a loop with no inner loops.
    - A **supermesh** is a combination of multiple meshes that share a common current source.

Mesh / loop analysis is used to determine unknown currents, using KVL instead of KCL to create a system of equations.

1. Assign mesh currents to each loop.
2. Use KVL and Ohm's law to get voltages in terms of mesh currents.
3. Solve the system of equations.

It may be easier to delete the branch of the current source in supermeshes, treating the region as one mesh with multiple mesh currents.

## Linearity

Circuits are linear if and only if their voltages, resistances, and currents can be expressed in terms of linear transformations of one another. They contain only linear loads, linear dependent sources, and independent souces.

$$\text{output}\propto\text{input}+C$$

!!! example
    Halving voltage must halve current (or at least halve it relative to a base current / voltage).
